<?php
/*********************************************************************************
 * The contents of this file are subject to the SugarCRM Public License Version 1.1.2
 * ("License"); You may not use this file except in compliance with the
 * License. You may obtain a copy of the License at http://www.sugarcrm.com/SPL
 * Software distributed under the License is distributed on an  "AS IS"  basis,
 * WITHOUT WARRANTY OF ANY KIND, either express or implied. See the License for
 * the specific language governing rights and limitations under the License.
 * The Original Code is:  SugarCRM Open Source
 * The Initial Developer of the Original Code is SugarCRM, Inc.
 * Portions created by SugarCRM are Copyright (C) SugarCRM, Inc.;
 * All Rights Reserved.
 ********************************************************************************/
$mod_strings = Array(
'LBL_MODULE_NAME'=>'Benutzer',
'LBL_MODULE_TITLE'=>'Benutzer: Home',
'LBL_SEARCH_FORM_TITLE'=>'Benutzer suchen',
'LBL_LIST_FORM_TITLE'=>'Benutzer',
'LBL_NEW_FORM_TITLE'=>'Neuer Benutzer',
'LBL_CREATE_NEW_USER'=>'Neuen Benutzer anlegen',
'LBL_LOGIN'=>'Login',
'LBL_USER_ROLE'=>'Rolle',
'LBL_LIST_NAME'=>'Name',
'LBL_LIST_LAST_NAME'=>'Nachname',
'LBL_LIST_USER_NAME'=>'Benutzername',
'LBL_LIST_DEPARTMENT'=>'Abteilung',
'LBL_LIST_EMAIL'=>'E-Mail',
'LBL_LIST_PRIMARY_PHONE'=>'Telefon',
'LBL_LIST_ADMIN'=>'Admin',
'LBL_LIST_CONFIRM_PASSWORD'=>'Password bestätigen',
'LBL_LIST_USER_NAME_ROLE'=>'CRM Nutzer',
'LBL_LIST_SELECT'=>'Auswählen',
'LBL_LIST_PHONE'=>'Telefon',
'LBL_LIST_NO'=>'#',

'LBL_ADMINS'=>'Administratoren',
'LBL_STD_USERS'=>'Standardnutzer',

'UserName'=>'Nutzername',
'Name'=>'Name',
'Tools'=>'Werkzeuge',


//added for patch2
'LBL_GROUP_NAME'=>'Gruppe',
'LBL_CURRENCY_NAME'=>'Währung',

'LBL_NEW_USER_BUTTON_TITLE'=>'Neuer Benutzer [Alt+N]',
'LBL_NEW_USER_BUTTON_LABEL'=>'Neuer Benutzer',
'LBL_NEW_USER_BUTTON_KEY'=>'N',
'LBL_DATE_FORMAT'=>'Datumsformat',

'LBL_ERROR'=>'Fehler:',
'LBL_PASSWORD'=>'Passwort / Password',
'LBL_USER_NAME'=>'Name / User Name',
'LBL_CRM_ID'=>'CRM Nr.',
'LBL_FIRST_NAME'=>'Vorname',
'LBL_LAST_NAME'=>'Nachname',
'LBL_YAHOO_ID'=>'Yahoo ID',
'LBL_THEME'=>'Oberfläche / Theme',
'LBL_LANGUAGE'=>'Sprache / Language',
'LBL_ADMIN'=>'Admin',
'LBL_OFFICE_PHONE'=>'Tel. gesch.',
'LBL_REPORTS_TO'=>'Vorgesetzter',
'LBL_OTHER_PHONE'=>'Andere Tel.',
'LBL_OTHER_EMAIL'=>'Andere E-Mail',
'LBL_DEPARTMENT'=>'Abteilung',
'LBL_STATUS'=>'Status',
'LBL_TITLE'=>'Funktion:',
'LBL_ANY_PHONE'=>'Weiteres Tel.:',
'LBL_ANY_EMAIL'=>'Weitere E-Mail:',
'LBL_ADDRESS'=>'Adresse',
'LBL_CITY'=>'Ort',
'LBL_STATE'=>'Bundesland',
'LBL_POSTAL_CODE'=>'PLZ',
'LBL_COUNTRY'=>'Land',
'LBL_USER_SETTINGS'=>'Einstellungen',
'LBL_USER_INFORMATION'=>'Benutzerinformationen',
'LBL_MOBILE_PHONE'=>'Mobil',
'LBL_OTHER'=>'Andere',
'LBL_FAX'=>'Fax',
'LBL_EMAIL'=>'E-Mail',
'LBL_HOME_PHONE'=>'Tel. privat',
'LBL_ADDRESS_INFORMATION'=>'Adressinformation',
'LBL_CAL_HRFORMAT'=>'Zeitformat des Kalenders',
'LBL_CAL_DURATION'=>'Tage beginnen mit',
'LBL_PRIMARY_ADDRESS'=>'Adresse:',

'LBL_CHANGE_PASSWORD_BUTTON_TITLE'=>'Passwort ändern [Alt+P]',
'LBL_CHANGE_PASSWORD_BUTTON_KEY'=>'P',
'LBL_CHANGE_PASSWORD_BUTTON_LABEL'=>'Passwort ändern',
'LBL_LOGIN_BUTTON_TITLE'=>'Login [Alt+L]',
'LBL_LOGIN_BUTTON_KEY'=>'L',
'LBL_LOGIN_BUTTON_LABEL'=>'Login',
'LBL_LOGIN_HISTORY_BUTTON_TITLE'=>'Loginverlauf [Alt+H]',
'LBL_LOGIN_HISTORY_BUTTON_KEY'=>'H',
'LBL_LOGIN_HISTORY_BUTTON_LABEL'=>'Loginverlauf',
'LBL_LOGIN_HISTORY_TITLE'=>'Benutzer: Loginverlauf',
'LBL_RESET_PREFERENCES'=>'Standardwerte zurücksetzen',

'LBL_CHANGE_PASSWORD'=>'Passwort ändern',
'LBL_OLD_PASSWORD'=>'Altes Passwort:',
'LBL_NEW_PASSWORD'=>'Neues Passwort:',
'LBL_CONFIRM_PASSWORD'=>'Passwort bestätigen:',
'ERR_ENTER_OLD_PASSWORD'=>'Bitte altes Passwort eingeben.',
'ERR_ENTER_NEW_PASSWORD'=>'Bitte neues Passwort eingeben.',
'ERR_ENTER_CONFIRMATION_PASSWORD'=>'Zum Bestätigen Passwort nochmals eingeben.',
'ERR_REENTER_PASSWORDS'=>'Bitte Passwörter nochmals eingeben.  Die \"new password\" und \"confirm password\" Werte stimmen nicht überein.',
'ERR_INVALID_PASSWORD'=>'Falscher Benutzername oder falsches Passwort',
'ERR_PASSWORD_CHANGE_FAILED_1'=>'Passwortänderung für Benutzer ',
'ERR_PASSWORD_CHANGE_FAILED_2'=>' nicht erfolgreich.  Ein neues Passwort muss gesetzt werden.',
'ERR_PASSWORD_INCORRECT_OLD'=>'Altes Passwort für Benutzer $this->user_name. Bitte nochmals eingeben..',
'ERR_USER_NAME_EXISTS_1'=>'Benutzername ',
'ERR_USER_NAME_EXISTS_2'=>' existiert bereits.  Doppelte Benutzernamen sind nicht möglich.<br>Wechseln Sie den Benutzernamen.',
'ERR_LAST_ADMIN_1'=>'Benutzername ',
'ERR_LAST_ADMIN_2'=>' ist der einzigste Administrator.  Mindestens ein Benutzer muss Adminstratorenrechte besitzen.<br>Prüfen Sie die Einstellungen.',

'ERR_DELETE_RECORD'=>"Zum Löschen muss ein Eintrag markiert werden.",

// Additional Fields for i18n --- Release vtigerCRM 3.2 Patch 2
// Users--listroles.php , createrole.php , ListPermissions.php , editpermissions.php

'LBL_ROLES'=>'Rollen',
'LBL_ROLES_SUBORDINATES'=>'Rollen und Unterstellte',

'LBL_CREATE_NEW_ROLE'=>'Neue Rolle erstellen',
'LBL_INDICATES_REQUIRED_FIELD'=>'Eingabe zwingend erforderlich',
'LBL_NEW_ROLE'=>'Neue Rolle',
'LBL_PARENT_ROLE'=>'Übergeordnete Rolle',

'LBL_LIST_ROLES'=>'Rollen anzeigen',
'LBL_ENTITY_LEVEL_PERMISSIONS'=>'Zugriffsrechte',
'LBL_ENTITY'=>'Dateneinheit',
'LBL_CREATE_EDIT'=>'Erstellen/Ändern',
'LBL_DELETE'=>'Löschen',
'LBL_LEADS'=>'Leads',
'LBL_ACCOUNTS'=>'Organisationen',
'LBL_CONTACTS'=>'Personen',
'LBL_OPPURTUNITIES'=>'Verkaufspotentiale',
'LBL_TASKS'=>'Aufgaben',
'LBL_CASES'=>'Vorfall',
'LBL_EMAILS'=>'E-Mails',
'LBL_NOTES'=>'Notizen',
'LBL_MEETINGS'=>'Meetings',
'LBL_CALLS'=>'Telefonate',
'LBL_IMPORT_PERMISSIONS'=>'Berechtigungen importieren',
'LBL_IMPORT_LEADS'=>'Leads importieren',
'LBL_IMPORT_ACCOUNTS'=>'Organisationen importiern',
'LBL_IMPORT_CONTACTS'=>'Personen importieren',
'LBL_IMPORT_OPPURTUNITIES'=>'Verkaufspotentiale importieren',

'LBL_ROLE_DETAILS'=>'Rollendetails',
//added for vtigercrm4 rc
'LBL_FILE'=> 'Dateiname',
'LBL_FILE_TYPE'=>'File Type',
'LBL_UPLOAD'=>'Datei hochladen',
'LBL_ATTACH_FILE'=>'Datei anfügen',
'LBL_EMAIL_TEMPLATES'=>'E-Mail Vorlage',
'LBL_TEMPLATE_HEADER'=>'Vorlage',
'LBL_TEMPLATE_DETAILS'=>'Vorlagendetails',
'LBL_EDIT_TEMPLATE'=>'Bearbeite Vorlage',
'LBL_TEMPLATE_FILE'=>'Vorlagedatei',
'LBL_EMAIL_TEMPLATES_LIST'=>'E-Mail Vorlagen auflisten',
'LBL_MAILMERGE_TEMPLATES_LIST'=>' > Kommunikationsvorlagen > Mail Merge Vorlagen',
'LBL_MAILMERGE_TEMPLATES_ATTACHMENT' => '> Kommunikationsvorlagen > Mail Merge Vorlage anfügen',
'LBL_DOWNLOAD_NOW'=>'Download jetzt',
'LBL_DOWNLOAD'=>'Download',
'LBL_SELECT_MODULE'=>'Modul auswählen',
'LBL_MERGE_FILE'=>'Datei : ',
'LBL_MERGE_MSG'=>'Bitte ein Modul für diese Vorlage auswählen.',
'LBL_MERGE_FIELDS'=>'Verbundene Felder',
'LBL_COPY_PASTE'=>'Kopieren & Einfügen',
'LNK_GO_TO_TOP'=>'nach oben',
'LBL_COLON'=>':',
'LBL_EMAIL_TEMPLATE'=>'E-Mail Vorlage',
'LBL_NEW_TEMPLATE'=>'Neue Vorlage',
'LBL_ADD_TEMPLATE'=>'Vorlage hinzufügen',
'LBL_USE_MERGE_FIELDS_TO_EMAIL_CONTENT'=>'Benutzen Sie die Ersetzungsfelder um Ihre E-Mails zu personalisieren.',
'LBL_AVAILABLE_MERGE_FIELDS'=>'Verfügbare Ersetzungsfelder',
'LBL_SELECT_FIELD_TYPE'=>'Feldtyp wählen',
'LBL_SELECT_FIELD'=>'Feld wählen',
'LBL_MERGE_FIELD_VALUE'=>'Wert des Ersetzungsfeldes kopieren',
'LBL_CONTACT_FIELDS'=>'Personenfelder',
'LBL_ACCOUNT_FIELDS'=>'Organisationsfelder',
'LBL_LEAD_FIELDS'=>'Lead',
'LBL_COPY_AND_PASTE_MERGE_FIELD'=>'Kopieren Sie das Ersetzungsfeld in die untenstehende E-Mailvorlage.',
'LBL_EMAIL_TEMPLATE_INFORMATION'=>'E-Mail Vorlage Information:',
'LBL_FOLDER'=>'Ordner:',
'LBL_PERSONAL'=>'Persönlich',
'LBL_PUBLIC'=>'Öffentlich',
'LBL_TEMPLATE_NAME'=>'Vorlagenname:',
'LBL_SUBJECT'=>'Betreff',
'LBL_BODY'=>'E-Mail Text',
'LBL_TEMPLATE_TOOLS'=>'Werkzeuge',
'LBL_TEMPLATE_PUBLIC'=>'Öffentlicher Zugang',
'LBL_TEMPLATE_PRIVATE'=>'Privater Zugang',
'LBL_TEMPLATE_SUBJECT'=>'E-Mail Betreff',
'LBL_TEMPLATE_MESSAGE'=>'E-Mail Nachricht',
'LBL_VIEWING'=>'Ansehen',
'LBL_PROPERTIES'=>'Eigentum von',


//added to fix the issue #6630
'LBL_ASTERISKEXTENSIONS_EXIST' => 'Die Asterisk Erweiterung gibt es bereits!',

// Added fields in createnewgroup.php
'LBL_CREATE_NEW_GROUP'=>'Erstelle neue Gruppe',
'LBL_NEW_GROUP'=>'Neue Gruppe',
'LBL_EDIT_GROUP'=>'Gruppe bearbeiten',
'LBL_GROUP_NAME'=>'Gruppenname',
'LBL_GROUP_DETAILS'=>'Gruppendetails',
'LBL_MEMBER'=>'Mitglieder',
'LBL_MEMBER_AVLBL'=>'Verfügbare Mitglieder',
'LBL_MEMBER_SELECTED'=>'Mitglieder auswählen',
'LBL_GROUP_MESG1'=>'Gruppen sind sehr zweckmäßig, um in komplexen Organisationen Rechte zu vergeben. Sie können Rollen, Nutzer, Profile und auch existierende Gruppen zu neuen Gruppen zusammenfassen.',
'LBL_GROUP_MESG2'=>'Um eine Gruppenmitglied hinzuzufügen, wählen Sie links die Quelle und klicken Sie auf den ">>" Button.',
'LBL_GROUP_MESG3'=>'Um ein Gruppenmitglied zu entfernen, wählen Sie rechts ein Gruppenmitglied und klicken Sie auf den "<<" Button.',


// Added fields in detailViewmailtemplate.html,listgroupmembers.php,listgroups.php
'LBL_DETAIL_VIEW_OF_EMAIL_TEMPLATE'=>'Detailansicht der E-Mail Vorlage',
'LBL_DETAIL_VIEW'=>'Detailansicht von',
'LBL_EDIT_VIEW'=>'Editieransicht von',
'LBL_EDITING'=>'Benutzer bearbeiten',
'LBL_GROUP_MEMBERS_LIST'=>'Gruppenmitgliederliste',
'LBL_GROUPS'=>'Gruppen',
'LBL_MY_GROUPS'=>'Meine Gruppen',
'LBL_ADD_GROUP_BUTTON'=>'Gruppe hinzufügen',
'LBL_WORD_TEMPLATES'=>'Wordvorlagen',
'LBL_NEW_WORD_TEMPLATE'=>'Neue Wordvorlage',
'LBL_EMAIL_TEMPLATE_DESC'=>'Bearbeite E-Mail Vorlagen, die für Kampagnen und Massen E-Mails benutzt werden',
'LBL_NAME'=>'Name',

// Added fields in TabCustomise.php,html and UpdateTab.php,html
'LBL_CUSTOMISE_TABS'=>'Register anpassen',
'LBL_CHOOSE_TABS'=>'Register wählen',
'LBL_AVAILABLE_TABS'=>'Verfügbare Register',
'LBL_SELECTED_TABS'=>'Gewählte Register',
'LBL_USER'=>'Benutzer',
'LBL_TAB_MENU_UPDATED'=>'Registermenu ist akutalisert. Bitte gehen Sie zu ',
'LBL_TO_VIEW_CHANGES'=>' um die Änderungen zu sehen',

// Added to change homepage order
'LBL_CHANGE_HOMEPAGE_LABEL'=>'Reihenfolge auf Startseite',
'LBL_CHANGE_HOMEPAGE_TITLE'=>'Startseite',

// Added fields in binaryfilelist.php
'LBL_OERATION'=>'Operation',

// Added fields in CreateProfile.php
'LBL_PROFILE_NAME'=>'Erstelle neues Profil:',
'LBL_NEW_PROFILE'=>'Neues Profil',
'LBL_NEW_PROFILE_NAME'=>'Profilname',
'LBL_PARENT_PROFILE'=>'Profilvorlage',
'LBL_BASIC_PROFILE_DETAILS'=>'Details der Profile',
'LBL_STEP_1_2'=>'Schritt 1 von 2',
'LBL_STEP_2_2'=>'Schritt 2 von 2',
'LBL_STEP'=>'Schritt',
'LBL_SELECT_BASE_PROFILE'=>'Profil auswählen',
'LBL_PROFILE_PRIVILEGES'=>'Profil Privilegien',
'LBL_GLOBAL_PRIVILEGES'=>'Globale Privilegien',
'LBL_TAB_PRIVILEGES'=>'Tab Privilegien',
'LBL_FIELD_PRIVILEGES'=>'Feld Privilegien',
'LBL_STANDARD_PRIVILEGES'=>'Standard Privilegien',
'LBL_UTILITY_PRIVILEGES'=>'Dienstprogramm Privilegien',
'LBL_UTILITIES'=>'Dienstprogramme',
'LBL_BASE_PROFILE_MESG'=>'Ich will ein vorhandenes Profil als Vorlage nutzen und die Privilegien festlegen. <b>(Empfohlen)</b>',
'LBL_BASE_PROFILE'=>'Profil:',
'LBL_OR'=>'ODER',
'LBL_BASE_PROFILE_MESG_ADV'=>'Ich will alles selbst machen <b>(Fortgeschrittene Benutzer)</b>',
'LBL_FOR'=>'für',
'LBL_GLOBAL_MESG_OPTION'=>'Wählens Sie die Optionen, um die globalen Privilegien zu ändern.',
'LBL_VIEW_ALL'=>'Alle ansehen',
'LBL_EDIT_ALL'=>'Alle bearbeiten',
'LBL_ALLOW'=>'Erlaubt',
'LBL_MESG_VIEW'=>'alle Informationen/Module zu sehen',
'LBL_MESG_EDIT'=>'das Bearbeiten von allen Informationen/Modulen',
'LBL_STD_MESG_OPTION'=>'Wählen Sie die Standartaktionen aus, die erlaubt werden sollen.',
'LBL_TAB_MESG_OPTION'=>'Wählen Sie die Tabs/Module, die erlaubt werden sollen.',
'LBL_UTILITY_MESG_OPTION'=>'Wählen Sie die Hilfsprogramme, die erlaubt werden sollen.',
'LBL_FIELD_MESG_OPTION'=>'Wählen Sie die Felder, die erlaubt werden sollen.',
'LBL_FINISH_BUTTON'=>'Fertig',
'LBL_PROFILE_DETAIL_VIEW'=>'Detailansicht des Profils',
'LBL_PROFILE_MESG'=>'Die Zugangsprivilegien ansehen für',
'LBL_PROFILE_M'=>'Profile',
'LBL_DEFINE_PRIV_FOR'=>' Definiere Privilegien für ',
'LBL_USE_OPTION_TO_SET_PRIV'=>'Benutzen Sie die nachfolgenden Optionen, um Privilegien zu setzen.',
'LBL_SUPER_USER_PRIV'=>'Übergeordnete Nutzerprivilegien',
'LBL_SET_PRIV_FOR_EACH_MODULE'=>'Setze Privilegien für jedes Modul ',
'LBL_FIELDS_AND_TOOLS_SETTINGS'=>'Feld- & Werkzeugprivilegien',
'LBL_SHOW_FIELDS'=>'Felder anzeigen',
'LBL_TOOLS_TO_BE_SHOWN'=>'Angezeigte Werkzeuge',
'LBL_WELCOME_PROFILE_CREATE'=>'Willkommen zum Profildesigner ',
'LBL_SELECT_CHOICE_NEW_PROFILE'=>'Bitte wählen Sie eine Option um ein neues Profil zu kreieren',
'LBL_ADD_CUSTOM_RULE'=>'Füge benutzerdefinierte Privilegienregel hinzu',
'LBL_EDIT_CUSTOM_RULE'=>'Bearbeite benutzerdefinierte Privilegienregel',
'LBL_CLOSE'=>'Schließen',
'LBL_SELECT_ENTITY'=>'Bitte eine Auswahl treffen',
'LBL_CAN_BE_ACCESSED_BY'=>'Kann zugegriffen werden durch',
'LBL_PERMISSIONS'=>'Erlaubnisse',
'LBL_ACCESS_RIGHTS_FOR_MODULES'=>'Zugangsrechte für Module',
'LBL_RULE_CONSTRUCTION'=>'Anzeige der Regeln:',
'LBL_ADD_RULE'=>'Regel hinzufügen',
'LBL_RELATED_MODULE_RIGHTS'=>'Rechte bezogener Module',
'LBL_IN_PERMISSION'=>'mit der Erlaubnis',

//Added fields in createrole.php
'LBL_HDR_ROLE_NAME'=>'Erstelle neue Rolle:',
'LBL_TITLE_ROLE_NAME'=>'Neue Rolle',
'LBL_ROLE_NAME'=>'Rollenname',
'LBL_ROLE_PROFILE_NAME'=>'Verbinde mit Profil',
'LBL_SPECIFY_ROLE_NAME'=>'Geben Sie der Rolle einen Namen :',
'LBL_ASSIGN_PROFILE'=>'Profil(e) zuordnen',
'LBL_PROFILE_SELECT_TEXT'=>'Wählen Sie das Profil und klicken Sie auf den Button',
'LBL_PROFILES_AVLBL'=>'Verfügbare Profile',
'LBL_ASSIGN_PROFILES'=>'Zugeordnete Profile',
'LBL_REPORTS_TO_ROLE'=>'Berichtet zu Rolle',
'LBL_ASSOCIATED_PROFILES'=>'Verbundene Profile :',
'LBL_ASSOCIATED_USERS'=>'Verbundene Benutzer :',


//Added fields in OrgSharingDetailsView.php
'LBL_ORG_SHARING_PRIVILEGES'=>'CRM Module',
'LBL_EDIT_PERMISSIONS'=>'Ändere Berechtigungen',
'LBL_SAVE_PERMISSIONS'=>'Speichere Berechtigungen',
'LBL_READ_ONLY'=>'Alle: Nur Lesen',
'LBL_EDIT_CREATE_ONLY'=>'Alle: Lesen, Erstelle/Bearbeiten',
'LBL_READ_CREATE_EDIT_DEL'=>'Alle: Lesen, Erstellen/Bearbeiten, Löschen',
'LBL_PRIVATE'=>'Privat',

//Added fields in listnotificationschedulers.php
'LBL_HDR_EMAIL_SCHDS'=>'Benutzer : E-Mail Benachrichtigungen',
'LBL_EMAIL_SCHDS_DESC'=>'Automatische E-Mail Benachrichtigungen werden beim Eintreten der folgenden Ereignisse erstellt',
'LBL_ACTIVE'=>'Aktiv',
'LBL_INACTIVE'=>'Inaktiv',
'LBL_NOTIFICATION'=>'Ereignis',
'LBL_DESCRIPTION'=>'Beschreibung',
'LBL_TASK_NOTIFICATION'=>'Aufgabe verspätet',
'LBL_TASK_NOTIFICATION_DESCRITPION'=>'Aufgabe um mehr als 24h verspätet',
'LBL_MANY_TICKETS'=>'Zu viele Tickets',
'LBL_MANY_TICKETS_DESCRIPTION'=>'Zu viele Tickets bei einem Vorfall. Kann darauf hinweisen, dass Servicelevel nicht eingehalten werden kann',
'LBL_PENDING_TICKETS'=>'Offene Tickets',
'LBL_TICKETS_DESCRIPTION'=>'Statusmeldung über offene Tickets',
'LBL_START_NOTIFICATION'=>'Start Supportfall',
'LBL_START_DESCRIPTION'=>'Nachricht über einen neuen Supportfall',
'LBL_BIG_DEAL'=>'grosses Geschäft',
'LBL_BIG_DEAL_DESCRIPTION'=>'Mitteilung über ein grösseres Geschäft',
'LBL_SUPPORT_NOTICIATION'=>'Supportfall beendet',
'LBL_SUPPORT_DESCRIPTION'=>'Mitteilung über einen abgeschlossenen Supportfall',
'LBL_BUTTON_UPDATE'=>'aktualisieren',
'LBL_MODULENAMES'=>'Module',

//Added fields in ListFieldPermissions.html
'LBL_FIELD_PERMISSION_FIELD_NAME'=>'Feldname',
'LBL_FIELD_PERMISSION_VISIBLE'=>'Sichtbarkeit',
'LBL_FIELD_PERMISSIOM_TABLE_HEADER'=>'Standardfelder',
'LBL_FIELD_LEVEL_ACCESS'=>'Sichtbarkeit',

//Added fields after 4.0.1
'LBL_SIGNATURE'=>'E-Mail Signatur',

//Added for Event Reminder 4.2 Alpha release
'LBL_ACTIVITY_NOTIFICATION'=>'Erinnerung',
'LBL_ACTIVITY_REMINDER_DESCRIPTION'=>'Erinnerungszeit vor dem Termin',
'LBL_MESSAGE'=>'Nachricht',

//Added for Global Privileges

'Public: Read Only'=>'Öffentlich: nur Lesen',
'Public: Read, Create/Edit'=>'Öffentlich: Lesen, Erzeugen/Bearbeiten',
'Public: Read, Create/Edit, Delete'=>'Öffentlich: Lesen, Erzeugen/Bearbeiten, Löschen',
'Private'=>'Privat',
'Hide Details'=>'verberge Details',
'Hide Details and Add Events'=>'verberge Details und erlaube das Hinzufügen von Ereignissen',
'Show Details'=>'Details anzeigen',
'Show Details and Add Events'=>'zeige Details und erlaube das Hinzufügen von Ereignissen',

'LBL_USR_CANNOT_ACCESS'=>'Kein Zugang auf anderen Benutzers ',
'LBL_USR_CAN_ACCESS'=>'Benutzerberechtigung ',
'LBL_USR_OTHERS'=>' für andere Benutzers ',

'Read Only '=>'nur Lesen ',
'Read, Create/Edit, Delete '=>'Lesen, Erzeugen/Bearbeiten, Löschen ',
'Read, Create/Edit '=>'Lesen, Erzeugen/Bearbeiten ',
'Read/Write'=>'Lesen/Schreiben',
'LBL_GO_TO_TOP'=>'nach Oben',
'LNK_CLICK_HERE'=>'klick hier',
'LBL_RULE_NO'=>'Regel Nr.',
'LBL_CAN_BE_ACCESSED'=>'kann zugegriffen werden durch',
'LBL_PRIVILEGES'=>'Privilegien',
'LBL_OF'=>'von',



//Added for 4.2GA support for mail server integration
'LBL_ADD_MAILSERVER_BUTTON_TITLE'=>'Mailserver hinzufügen',
'LBL_ADD_MAILSERVER_BUTTON_KEY'=>'M',
'LBL_ADD_MAILSERVER_BUTTON_LABEL'=>'Mailserver hinzufügen',

'LBL_LIST_MAILSERVER_BUTTON_TITLE'=>'Mailserver auflisten',
'LBL_LIST_MAILSERVER_BUTTON_KEY'=>'L',
'LBL_LIST_MAILSERVER_BUTTON_LABEL'=>'Mailserver auflisten',
//added for inventory terms and conditions
'INV_TANDC'=>'Regeln und Vorschriften',
'INV_TERMSANDCONDITIONS'=>'Regeln und Vorschriften für Lager',
'LBL_INV_TERMSANDCONDITIONS'=>'Lagermanagement',


'INVENTORYNOTIFICATION'=>'Bestandsmeldungen',
'LBL_INVENTORY_NOTIFICATIONS'=>'Bearbeite E-Mail für Bestandesmeldungen',
'LBL_INV_NOT_DESC'=>'Benachrichtigungs-Mails, welche automatisch auf Grund der Aufträge und des Minimalbestandes an den Einkäufer gesandt wurden.',

'InvoiceNotification'=>'Lagerbestandsmeldung während Rechungsstellung',
'InvoiceNotificationDescription'=>'Wenn der Minimalbestand erreicht wird, wird eine automatische Benachrichtigung an den Einkäufer gesandt.',

'QuoteNotification'=>'Lagerbestandsmeldung während Angebotserstellung',
'QuoteNotificationDescription'=>'Diese Nachricht wird versendet, wenn der Lagerbestand kleiner ist, als die Anzahl der im Angebot aufgeführten Produkte',

'SalesOrderNotification'=>'Lagerbestandsmeldung während der Verkaufs-Erstellung',
'SalesOrderNotificationDescription'=>'Wenn der Lagerbestand kleiner ist als die Menge, welche im Verkauf bestätigt wird.',

//New addition for 4.2 GA
'LBL_USER_FIELDS'=>'Benutzerfelder',
'LBL_NOTE_DO_NOT_REMOVE_INFO'=>'Bemerkung: Werte zwischen {  } dürfen nicht gelöscht oder geändert werden.',

//Added for patch2
'LBL_FILE_INFORMATION'=>'Dateiinformation',

//Added after pathc2
'LBL_LEAD_FIELD_ACCESS'=>'Feldzugang für Leads',

'LBL_ACCOUNT_FIELD_ACCESS'=>'Feldzugang für Organisatonen',

'LBL_CONTACT_FIELD_ACCESS'=>'Feldzugang für Personen',

'LBL_OPPORTUNITY_FIELD_ACCESS'=>'Feldzugang für Potentiale',

'LBL_HELPDESK_FIELD_ACCESS'=>'Feldzugang für HelpDesk',

'LBL_PRODUCT_FIELD_ACCESS'=>'Feldzugang für Produkte',

'LBL_NOTE_FIELD_ACCESS'=>'Feldzugang für Notizen',

'LBL_EMAIL_FIELD_ACCESS'=>'Feldzugang für E-Mails',

'LBL_TASK_FIELD_ACCESS'=>'Feldzugang für Aufgaben',

'LBL_EVENT_FIELD_ACCESS'=>'Feldzugang für Anrufe/Termine',
'LBL_VENDOR_FIELD_ACCESS'=>'Feldzugang für Lieferanten',
'LBL_PB_FIELD_ACCESS'=>'Feldzugang für Preislisten',
'LBL_QUOTE_FIELD_ACCESS'=>'Feldzugang für Angebote',
'LBL_PO_FIELD_ACCESS'=>'Feldzugang für Einkäufe',
'LBL_SO_FIELD_ACCESS'=>'Feldzugang für Verkäufe',
'LBL_INVOICE_FIELD_ACCESS'=>'Feldzugang für Rechnungen',

//given for calendar color for an user user
'LBL_COLOR'=>'Farbe im Kalender',
//added for activity view in home page
'LBL_ACTIVITY_VIEW'=>'Standard Aktivitätenansicht',
//Added to change Home page order
'LBL_HOMEPAGE_ORDER_UPDATE'=>'Update die Reihenfolge der Blöcke auf Home',
'LBL_HOMEPAGE_ID'=>'Blockreihenfolge',
'ERR_INVALID_USER'=>'Unerlaubter Zugangsversuch -- Bitte kontaktieren Sie den Administrator',
'ALVT'=>'meine top Organisationen',
'PLVT'=>'meine top Potentiale',
'QLTQ'=>'meine top Angebote',
'CVLVT'=>'Ausgewählte Bewertungslisten',
'HLT'=>'Meine Tickets',
'OLV'=>'Aktuelle und unerledigte Aktivitäten',
'GRT'=>'Meine Gruppenzugehörigkeit',
'OLTSO'=>'Meine wichtigsten Verkäufe',
'ILTI'=>'Meine Top Offenen Rechnungen',
'HDB'=>'Startseite Cockpit',
'OLTPO'=>'Meine Top Offenen Einkaufsbestellungen',
'LTFAQ'=>'Meine Wissensbasis',
'UA'=>'geplante Aktivitäten',
'PA'=>'überfällige Aktivitäten',

//Added for 5.0 alpha
'LBL_GROUP_NAME_ERROR'=>'Gruppenname existiert bereits!',
'MNL'=>'Meine neuen Leads',
'LBL_LEAD_VIEW'=>'Standard Lead-Ansicht',
'LBL_TAG_CLOUD'=>'Tag Wolke',
'LBL_LIST_TOOLS'=>'Operationen',
'LBL_STATISTICS'=>'Statistik',
'LBL_TOTAL'=>'Total :',
'LBL_OTHERS'=>'Andere :',
'LBL_USERS'=>'Benutzer',
'LBL_USER_LOGIN_ROLE'=>'Benutzer Login & Rolle',
'LBL_USER_MORE_INFN'=>'Mehr Informationen',
'LBL_USER_ADDR_INFN'=>'Adressinformation',
'LBL_USER_IMAGE'=>'Benutzer Bild',
'LBL_USR'=>'Benutzer',

'LBL_MY'=>'Meine',
'LBL_MY_DEFAULTS'=>'Meine Standards',
'LBL_MY_DESG'=>'Meine Kontaktdetails',
'LBL_MY_ADDR'=>'Meine Postadresse',
'LBL_MY_PHOTO'=>'Mein Photo',
'LBL_CHANGE_PHOTO'=>'Ändere Photo...',
'LBL_CHANGE'=>'Ändern',


//Added for Access Privileges

'LBL_GLOBAL_FIELDS_MANAGER'=>'Globaler Feldmanager',
'LBL_GLOBAL_ACCESS_PRIVILEGES'=>'Globale Zugangsregeln',
'LBL_CUSTOM_ACCESS_PRIVILEGES'=>'Benutzerdefinierte Zugangsregeln',
'LBL_BOTH'=>'Beide',
'LBL_VIEW'=>'Ansehen',
'LBL_RECALCULATE_BUTTON'=>'Berechnen',
'LBL_ADD_PRIVILEGES_BUTTON'=>'Privilegien hinzufügen',
'LBL_CUSTOM_ACCESS_MESG'=>'Keine benutzerdefinierte Zugangsregel definiert.',
'LBL_CREATE_RULE_MESG'=>'um eine neue Regel zu erzeugen',
'LBL_SELECT_SCREEN'=>'Wählen Sie die Ansicht / Module :',
'LBL_FIELDS_AVLBL'=>'Felder verfügbar in',
'LBL_FIELDS_SELECT_DESELECT'=>'Wählen Sie die Felder, die angezeigt werden sollen.',
'LBL_ROLE_TO_BE_DELETED'=>'Zu löschende Rolle',
'LBL_TRANSFER_USER_ROLE'=>'Übertrage Benutzer zu Rolle',
'LBL_DELETE_ROLE'=>'Rolle Löschen',
'LBL_MORE_INFORMATION'=>'Mehr Informationen',
'LBL_USERLOGIN_ROLE'=>'Benutzer Login & Rolle',
'LBL_USER_IMAGE_INFORMATION'=>'Benutzerbild',

//Added for 5.0 for all fields
'Role'=>'Rolle',
'Email'=>'E-Mail',
'Admin'=>'Administratorrechte',
'User Name'=>'Nutzername',
'First Name'=>'Vorname',
'Last Name'=>'Nachname',
'Status'=>'Status',
'Default Activity View'=>'Standardkalenderansicht',
'Default Lead View'=>'Standard Lead-Ansicht',
'Currency'=>'Währung',
'Title'=>'Funktion',
'Office Phone'=>'Telefon Büro',
'Department'=>'Abteilung',
'Mobile'=>'Mobil',
'Reports To'=>'Berichtet an',
'Other Phone'=>'Weiteres Telefon',
'Other Email'=>'andere E-Mail',
'Fax'=>'Fax',
'Yahoo id'=>'weitere E-Mail',
'Home Phone'=>'Telefon privat',
'User Image'=>'Photo laden',
'Date Format'=>'Datumsformat',
'Tag Cloud'=>'Tag Wolke',
'Signature'=>'E-Mail Signatur',
'Documents'=>'Notizen',
'Street Address'=>'Strasse',
'City'=>'Ort',
'State'=>'Bundesland',
'Postal Code'=>'PLZ',
'Country'=>'Land',
'Password'=>'Passwort',
'Confirm Password'=>'Passwort bestätigen',
'LBL_SHOWN'=>'angezeigt',
'LBL_HIDDEN'=>'verborgen',
'LBL_SHOW'=>'zeige',
'LBL_HIDE'=>'verberge',
'LBL_HOME_PAGE_COMP'=>' Startseitenbestandteile',
'LBL_LOGIN_HISTORY'=>' Login Historie',
'LBL_USERDETAIL_INFO'=>'Details des folgenden CRM Nutzers ansehen',
'LBL_DELETE_GROUP'=>'Gruppe löschen',
'LBL_DELETE_GROUPNAME'=>'Gruppe, die gelöscht werden soll',
'LBL_TRANSFER_GROUP'=>'Übertrage die Gruppe an: ',
'LBL_DELETE_USER'=>'Benutzer löschen',
'LBL_TRANSFER_USER'=>'Übertrage Nutzerdaten zu',
'LBL_DELETE_PROFILE'=>'Lösche Profile',
'LBL_TRANSFER_ROLES_TO_PROFILE'=>'Übertrage Rollen zu Profile',
'LBL_PROFILE_TO_BE_DELETED'=>'zu löschende Profile',

//Added for disabling window Recalculate

'LBL_RECALC_MSG'=>'Sind Sie sicher, dass Sie die Regeln neu berechnen lassen wollen? Das kann einige Zeit in Anspruch nehmen',
'LBL_YES'=>'Ja',
'LBL_NO'=>'Nein',

'LBL_MANDATORY_MSG'=>'Pflichtfelder',
'LBL_DISABLE_FIELD_MSG'=>'Felder durch die Einstellungen in Globaler Rechtevergabe gesperrt.',

//Added for About Us

'LBL_CONTACT_US'=>'Kontaktieren Sie uns',
'LBL_READ_LICENSE'=>'Lizenz lesen',
'LBL_VERSION'=>'Version',
'LBL_TEAM'=>'Team',
'LBL_CREDITS'=>'Beiträge von',
'LBL_THIRD_PARTY'=>'3rd Party Pakete',
'LBL_COMMUNITY'=>'und die vtiger Community',

'LBL_ASSIGN_ROLE'=>'Rolle zuweisen',

//Moved from Settings to here for Webmail client integration (for 5.0.3 release)

'LBL_ADD_MAIL_ACCOUNT'=>'Erstelle E-Mail Konto',
'LBL_NEW_MAIL_ACCOUNT_TITLE'=>'Neues E-Mail Konto [Alt+M]',
'LBL_NEW_MAIL_ACCOUNT_KEY'=>'M',
'LBL_NEW_MAIL_ACCOUNT_LABEL'=>'Neues E-Mail Konto',
'LBL_GENERAL_INFO'=>'Allgemeine Information',
'LBL_DISPLAY_NAME'=>'Angezeigter Name',
'LBL_MAIL_PROTOCOL'=>'Mail Protokoll',
'LBL_LIST_PASSWORD'=>'Passwort',
'LBL_MAIL_SERVER_NAME'=>'Mailserver Name oder IP',
'LBL_INCOME_SERVER_SETTINGS'=>'Incoming Server',
'LBL_TEST_SETTINGS'=>'Teste meine Kontoeinstellungen sofort',
'LBL_TEST_BUTTON_TITLE'=>'Teste meine Kontoeinstellungen jetzt! [Alt+T]',
'LBL_TEST_BUTTON_KEY'=>'T',
'LBL_TEST_BUTTON_LABEL'=>'Teste meine Kontoeinstellungen jetzt!',
'LBL_DEFAULT'=>'Standard',
'LBL_IMAP2'=>'IMAP2',
'LBL_IMAP4'=>'IMAP4',
'LBL_POP'=>'POP',
'LBL_IMAP'=>'IMAP',
'LBL_MAIL_DISCLAIM'=>'Angaben mit einer <font color="red">*</font> Markierung sind Pflichtfelder.<br>Angaben mit einer <font color="red">* *</font> Markierung werden nicht voll unterstützt.',
'LBL_SSL_OPTIONS'=>'SSL Optionen',
'LBL_TLS'=>'TLS',
'LBL_NO_TLS'=>'Kein TLS',
'LBL_CERT_VAL'=>'Zertifikatsvalidierung',
'LBL_INT_MAILER'=>'internes Mailprogramm benutzen?',
'LBL_INT_MAILER_USE'=>'Ja',
'LBL_INT_MAILER_NOUSE'=>'Nein',
'LBL_VAL_SSL_CERT'=>'Validiere SSL Cert',
'LBL_DONOT_VAL_SSL_CERT'=>'SSL Cert nicht validieren',
'LBL_WEB_MAIL_CONFIG'=>'Web Mail Konfiguration',
'LBL_CONFIGURE_WEB_MAIL'=>' - Konfiguriere Web Mail',
'LBL_LIST_MAIL_ACCOUNT'=>'  E-Mail Konto auflisten',
'LBL_MY_MAIL_SERVER_DET'=>'Meine Details vom Incoming Mailserver',
'LBL_MY_DETAILS'=>'Meine Details',
'LBL_EMAIL_ID'=>'E-Mail Adresse',
'LBL_EMAIL_ADDRESS'=>'E-Mail',
'LBL_NAME_EXAMPLE'=>'(Beispiel : Max Mustermann)',
'LBL_EMAIL_EXAMPLE'=>'(Beispiel : maxmustermann@xyz.de)',
'LBL_REFRESH_TIMEOUT'=>'Refresh Timeout',
'LBL_1_MIN'=>'1 Minute',
'LBL_2_MIN'=>'2 Minuten',
'LBL_3_MIN'=>'3 Minuten',
'LBL_4_MIN'=>'4 Minuten',
'LBL_5_MIN'=>'5 Minuten',
'LBL_EMAILS_PER_PAGE'=>'E-Mails pro Seite',
// Added for 5.0.3

'LBL_ENTER_PROFILE'=>'Profilnamen eingeben',
'TITLE_USER_DOCUMENT'=>'Dokument ohne Namen',
'TITLE_VTIGER_CRM_5'=>'crm',
'ROLE_DRAG_ERR_MSG'=>'Sie können keine übergeordnete Rolle unter eine untergeordnete Rolle verschieben.',

'LBL_NOTIFICATION_ACTIVITY'=>'automatische Benachrichtigung',
'LBL_NOTIFICATION_EMAIL_INFO'=>'E-Mail Information',
'LBL_GOTO_LISTVIEW_BUTTON'=>'zur Listenansicht gehen',

// Added/Updated for vtiger CRM 5.0.4

'LBL_SSL' => 'SSL',
//Added to fix the issue #4081
'LBL_USERNAME_EXIST' => 'Dieser Benutzername existiert bereits!',
'LBL_UNAUTHORIZED_ACCESS' => 'Sie haben keinen Zugang zur Administration!',
//Added to provide User based TagCloud
'LBL_TAGCLOUD_DISPLAY'=>'Tag Cloud Anzeige',
'INTERNAL_MAIL_COMPOSER'=>'internes E-Mail Programm',

// Added for 5.0.4 to Support Email notication on User Creation
'User Login Details'=>'Benutzer Login Details',
'LBL_TO_LOGIN' => 'zum Login',

// Added after 5.0.4 GA

'LBL_USER_ADV_OPTIONS'=>'erweiterte Optionen',
'Reminder Interval'=>'Erinnerungsintervall',
'Webservice Access Key'=>'Zugangsschlüssel',

//user-group fixes
'LBL_GROUPNAME_EXIST' => 'Eine Gruppe mit diesem amen gibt es bereits!',
'LBL_PROFILENAME_EXIST' => 'EIn Profil mit diesem Namen gibt es bereits!',

//Fixed For Asterisk Configration
'Asterisk Configuration' => 'Asterisk Konfiguration',
'Asterisk Extension' => 'Asterisk Erweiterung',
' Receive Incoming Calls' => 'empfange eingehende Anrufe',

// Added for Create Custom Fields 
'LBL_USER_CUSTOMFIELDS_DESCRIPTION' => 'Erstellen Sie benutzerdefinierte Felder für Users ',
'LBL_USER_CUSTOMFIELDS' => 'Benutzerdefinierte Felder für das Users-Modul',

'LBL_CURRENCY_CONFIGURATION'=> 'Währungseinstellungen',

'Time Zone'=>'Zeitzone',
'Language'=>'Sprache',
'Theme'=>'Theme',
'Decimal Separator'=>'Dezimaltrennzeichen',
'Symbol Placement'=>'Position des Währungssymbols',
'Digit Grouping Pattern'=>'Muster für Zahlengruppierungen',
'Digit Grouping Separator'=>'Trennzeichen für Zahlengruppierungen',

//Time zones-Dont change any value
'Kwajalein' => '(UTC-12:00) Internationale Datumsgrenze (Western)',
'Pacific/Midway' => '(UTC-11:00) Koordinierte Weltzeit-11',
'Pacific/Samoa' => '(UTC-11:00) Samoa',
'Pacific/Honolulu' => '(UTC-10:00) Hawaii',
'America/Anchorage' => '(UTC-09:00) Alaska',
'America/Los_Angeles' => '(UTC-08:00) Pazifik Zeit (USA &amp; Canada)',
'America/Tijuana' => '(UTC-08:00) Niederkalifornien',
'America/Denver' => '(UTC-07:00) Mountain Zeit (USA &amp; Canada)',
'America/Chihuahua' => '(UTC-07:00) Chihuahua, La Paz, Mazatlan',
'America/Mazatlan' => '(UTC-07:00) Mazatlan',
'America/Phoenix' => '(UTC-07:00) Arizona',
'America/Regina' => '(UTC-06:00) Saskatchewan',
'America/Tegucigalpa' => '(UTC-06:00) Mittelamerika',
'America/Chicago' => '(UTC-06:00) Central Zeit (USA &amp; Canada)',
'America/Mexico_City' => '(UTC-06:00) Mexico-Stadt',
'America/Monterrey' => '(UTC-06:00) Monterrey',
'America/New_York' => '(UTC-05:00) Eastern Zeit (USA &amp; Canada)',
'America/Bogota' => '(UTC-05:00) Bogota, Lima, Quito',
'America/Lima' => '(UTC-05:00) Lima',
'America/Rio_Branco' => '(UTC-05:00) Rio Branco',
'America/Indiana/Indianapolis' => '(UTC-05:00) Indiana (Ost)',
'America/Caracas' => '(UTC-04:30) Caracas',
'America/Halifax' => '(UTC-04:00) Atlantic (Kanada)',
'America/Manaus' => '(UTC-04:00) Manaus',
'America/Santiago' => '(UTC-04:00) Santiago',
'America/La_Paz' => '(UTC-04:00) La Paz',
'America/Cuiaba' => '(UTC-04:00) Cuiaba',
'America/Asuncion' => '(UTC-04:00) Asuncion',
'America/St_Johns' => '(UTC-03:30) Neufundland',
'America/Argentina/Buenos_Aires' => '(UTC-03:00) Buenos Aires',
'America/Sao_Paulo' => '(UTC-03:00) Brasilia',
'America/Godthab' => '(UTC-03:00) Grönland',
'America/Montevideo' => '(UTC-03:00) Montevideo',
'Atlantic/South_Georgia' => '(UTC-02:00) Mittelatlantik',
'Atlantic/Azores' => '(UTC-01:00) Azoren',
'Atlantic/Cape_Verde' => '(UTC-01:00) Kap Verde',
'Europe/London' => '(UTC) London, Edinburgh, Dublin, Lisbon',
'UTC' => '(UTC) Koordinierte Weltzeit',
'Africa/Monrovia' => '(UTC) Monrovia, Reykjavik',
'Africa/Casablanca' => '(UTC) Casablanca',
'Europe/Belgrade' => '(UTC+01:00) Belgrad, Bratislava, Budapest, Ljubljana, Prag',
'Europe/Sarajevo' => '(UTC+01:00) Sarajevo, Skopje, Warschau, Zagreb',
'Europe/Brussels' => '(UTC+01:00) Brüssel, Kopenhagen, Madrid, Paris',
'Africa/Algiers' => '(UTC+01:00) West-Zentralafrika',
'Europe/Amsterdam' => '(UTC+01:00) Amsterdam, Berlin, Bern, Rome, Stockholm, Wien',
'Europe/Minsk' => '(UTC+02:00) Minsk',
'Africa/Cairo' => '(UTC+02:00) Kairo',
'Europe/Helsinki' => '(UTC+02:00) Helsinki, Riga, Sofia, Tallinn, Wilna',
'Europe/Athens' => '(UTC+02:00) Athen, Bukarest',
'Europe/Istanbul' => '(UTC+02:00) Istanbul',
'Asia/Jerusalem' => '(UTC+02:00) Jerusalem',
'Asia/Amman' => '(UTC+02:00) Amman',
'Asia/Beirut' => '(UTC+02:00) Beirut',
'Africa/Windhoek' => '(UTC+02:00) Windhoek',
'Africa/Harare' => '(UTC+02:00) Harare',
'Asia/Kuwait' => '(UTC+03:00) Kuwait, Riad',
'Asia/Baghdad' => '(UTC+03:00) Bagdad',
'Africa/Nairobi' => '(UTC+03:00) Nairobi',
'Asia/Tehran' => '(UTC+03:30) Teheran',
'Asia/Tbilisi' => '(UTC+04:00) Tbilisi',
'Europe/Moscow' => '(UTC+04:00) Moskau, Wolgograd',
'Asia/Muscat' => '(UTC+04:00) Abu Dhabi, Muskat',
'Asia/Baku' => '(UTC+04:00) Baku',
'Asia/Yerevan' => '(UTC+04:00) Yerevan',
'Asia/Karachi' => '(UTC+05:00) Islamabad, Karatschi',
'Asia/Tashkent' => '(UTC+05:00) Taschkent',
'Asia/Kolkata' => '(UTC+05:30) Chennai, Kolkata, Mumbai, New Delhi',
'Asia/Colombo' => '(UTC+05:30) Sri Jayawardenepura',
'Asia/Katmandu' => '(UTC+05:45) Kathmandu',
'Asia/Dhaka' => '(UTC+06:00) Dakka',
'Asia/Almaty' => '(UTC+06:00) Almaty',
'Asia/Yekaterinburg' => '(UTC+06:00) Jekaterinburg',
'Asia/Rangoon' => '(UTC+06:30) Yangon (Rangun)',
'Asia/Novosibirsk' => '(UTC+07:00) Nowosibirsk',
'Asia/Bangkok' => '(UTC+07:00) Bangkok, Jakarta',
'Asia/Brunei' => '(UTC+08:00) Peking, Chongqing, Hongkong, Urumchi',
'Asia/Krasnoyarsk' => '(UTC+08:00) Krasnojarsk',
'Asia/Ulaanbaatar' => '(UTC+08:00) Ulan-Bator',
'Asia/Kuala_Lumpur' => '(UTC+08:00) Kuala Lumpur, Sinapur',
'Asia/Taipei' => '(UTC+08:00) Taipeh',
'Australia/Perth' => '(UTC+08:00) Perth',
'Asia/Irkutsk' => '(UTC+09:00) Irkutsk',
'Asia/Seoul' => '(UTC+09:00) Seoul',
'Asia/Tokyo' => '(UTC+09:00) Tokio',
'Australia/Darwin' => '(UTC+09:30) Darwin',
'Australia/Adelaide' => '(UTC+09:30) Adelaide',
'Australia/Canberra' => '(UTC+10:00) Canberra, Melbourne, Sydney',
'Australia/Brisbane' => '(UTC+10:00) Brisbane',
'Australia/Hobart' => '(UTC+10:00) Hobart',
'Asia/Vladivostok' => '(UTC+10:00) Vladivostok',
'Pacific/Guam' => '(UTC+10:00) Guam, Port Moresby',
'Asia/Yakutsk' => '(UTC+10:00) Jakutsk',
'Pacific/Fiji' => '(UTC+12:00) Fidschi',
'Asia/Kamchatka' => '(UTC+12:00) Kamchatka',
'Pacific/Auckland' => '(UTC+12:00) Auckland',
'Asia/Magadan' => '(UTC+12:00) Magadan',
'Pacific/Tongatapu' => '(UTC+13:00) Nukualofa',
);
?>